pub fn read_zip_entry(
path: &Path,
wanted: &str,
maximum_bytes: u64,
) -> Result<Vec<u8>>Expand description
Reads one small metadata entry without extracting the surrounding archive.
Errors
When the entry is missing, is not a regular file, or is larger than a metadata entry may be.