pub fn parse_document_kind(kind: &str) -> Option<ParsedDocumentKind>Expand description
Splits a kind back into its namespace and document type.
Returns None when the value is not a document kind at all.
pub fn parse_document_kind(kind: &str) -> Option<ParsedDocumentKind>Splits a kind back into its namespace and document type.
Returns None when the value is not a document kind at all.