pub fn payload_digest(entries: &[PayloadDigestEntry]) -> Result<PayloadDigest>Expand description
Serialises the entries and returns what a release carries about them.
Errors
When the entries cannot be serialised — see payload_digest_stream.
pub fn payload_digest(entries: &[PayloadDigestEntry]) -> Result<PayloadDigest>Serialises the entries and returns what a release carries about them.
When the entries cannot be serialised — see payload_digest_stream.