pub fn assert_native_host(adapter: &BoxTargetAdapter) -> Result<()>Expand description
Ensures this host is the operating system and architecture the box ships for.
Errors
When the current host is not the one the adapter requires.
pub fn assert_native_host(adapter: &BoxTargetAdapter) -> Result<()>Ensures this host is the operating system and architecture the box ships for.
When the current host is not the one the adapter requires.