box_target_id

Function box_target_id 

pub fn box_target_id(target: &BoxTarget) -> Result<String>
Returns the canonical target slug used in box filenames, object keys and routes.

Errors

When the target is outside the supported matrix, or its CUDA version is missing on a CUDA target or present on any other.