resolve_environment

Function resolve_environment 

pub fn resolve_environment(
    options: &ResolveOptions<'_>,
) -> Result<ResolvedEnvironment>
Merges the layers in precedence order and produces the masked diagnostic.

Errors

When a layer holds a name or value a process environment cannot carry.