verify_required_assets

Function verify_required_assets 

pub fn verify_required_assets(
    root: &Path,
    assets: &[AssetDescriptor],
) -> Result<()>
Checks the assets a caller was told to place, against their signed descriptors.

Errors

When an asset is missing, is not a regular file, or does not match its signed size or digest.