pub type SignalSender = Sender<ForwardedSignal>;Expand description
The sending half a caller keeps to forward signals into a running box.
Aliased Type
pub struct SignalSender { /* private fields */ }pub type SignalSender = Sender<ForwardedSignal>;The sending half a caller keeps to forward signals into a running box.
pub struct SignalSender { /* private fields */ }