pub struct VerifiedPayload {
pub bytes: Vec<u8>,
pub value: Value,
}Expand description
The payload of a document whose signature has verified.
Fields
bytes: Vec<u8>The exact bytes that were signed, which are also the bytes that were published.
value: ValueThose bytes parsed as JSON — only ever produced after a signature has verified.