pub fn inspect_release_document_with_keys(
release_document_path: &Path,
trusted: &[TrustedKey],
) -> Result<InspectedRelease>Expand description
The same inspection against keys a caller already holds in memory.
pub fn inspect_release_document_with_keys(
release_document_path: &Path,
trusted: &[TrustedKey],
) -> Result<InspectedRelease>The same inspection against keys a caller already holds in memory.