pub fn find_entry_through_link(entries: &[PayloadEntry]) -> Option<&str>Expand description
Rejects an entry set in which anything could be written through a link.
Returns the offending entry path, or None when the set is safe.
pub fn find_entry_through_link(entries: &[PayloadEntry]) -> Option<&str>Rejects an entry set in which anything could be written through a link.
Returns the offending entry path, or None when the set is safe.